
# Slot: model_activity_enabled_by_closure

The reflexive transitive closure of `model_activity_enabled_by_terms`, over the is_a and has_part relationship type (e.g. complex to parts)

URI: [gocam:queryIndex__model_activity_enabled_by_closure](https://w3id.org/gocam/queryIndex__model_activity_enabled_by_closure)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [TermObject](TermObject.md)

## Parents


## Children


## Used by

 * [QueryIndex](QueryIndex.md)
